Skip to contents

Given a data frame as input the function will calculate the clusters.

Usage

find_clusters(x)

Arguments

x

numeric matrix of data, or an object that can be coerced to such a matrix (such as a numeric vector or a data frame with all numeric columns).

Value

Returns a vector of factors representing arbitrary cluster number of the data_frame provided

Examples

if (FALSE) { # \dontrun{
data_frame <- datasets::USArrests
clusters <- find_clusters(datasets::USArrests)
} # }